<?php

namespace LakeDrops\ComposerScripts;

use Composer\Composer;
use Composer\EventDispatcher\EventSubscriberInterface;
use Composer\IO\IOInterface;
use Composer\Plugin\PluginInterface;
use Composer\Script\Event;
use Composer\Script\ScriptEvents;

/**
 * Composer plugin for handling drupal scaffold.
 */
class Plugin implements PluginInterface, EventSubscriberInterface {

  /**
   * The handler object for events.
   *
   * @var \LakeDrops\ComposerScripts\Handler
   */
  protected $handler;

  /**
   * {@inheritdoc}
   */
  public function activate(Composer $composer, IOInterface $io) {
    $this->handler = new Handler($composer, $io);
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return array(
      ScriptEvents::POST_CREATE_PROJECT_CMD => 'updateScripts',
      ScriptEvents::POST_INSTALL_CMD => 'updateScripts',
      ScriptEvents::POST_UPDATE_CMD => 'updateScripts',
    );
  }

  /**
   * Update scripts of all LakeDrops plugins.
   *
   * @param \Composer\Script\Event $event
   *   The event that triggered the plugin.
   */
  public function updateScripts(Event $event) {
    $this->handler->updateScripts($event);
  }

  /**
   * Callback to scan plugins for scripts.
   *
   * @param \Composer\Script\Event $event
   *   The event that triggered the plugin.
   */
  public static function scripts(Event $event) {
    $handler = new Handler($event->getComposer(), $event->getIO());
    $handler->updateScripts($event);
  }

}
